#[macro_export] macro_rules!
hide {
    (- $a:expr; $($arg:tt)*) => ($($arg)*);
    ($($arg:tt)*) => ($($arg)*);
}
